//////LIBRARIES
#include <plib.h> // for PIC specific functions
#include "NU32.h" // for NU32 board specific functions
#include "LCD.h" // for the 16x2 LCD

//////GLOBAL VARIABLES
// none used here

//////FUNCTION PROTOTYPES

//////MAIN
int main(void)
{
    NU32_Startup(); // from NU32.c, maximizes performance
    NU32_Initialize(); // from NU32.c, inits USER, L1 and L2, serial fns

    // init everything for the LCD
    setupLCD();
    LCDClear(0); // clear the LCD in case it still says something

    int i = 0;
    int j = 0;
    float k = 4.235;

    // infinite loop
    while(1)
    {
        sprintf(LCD_Out_Buffer,"i = %4d", i); // reserve at least 4 spaces for
                                                // the int by using %5d
        LCDWriteString(LCD_Out_Buffer, 1, 5); // write to the first row,
                                            // start at the 5th position
        i++;

        sprintf(LCD_Out_Buffer,"k = %5.2f", k); // reserve at least 5 spaces for
                                            // the float, including the .
                                            // and use exactly 2 decimal spaces
                                            // so we should miss the last digit
                                            // in this case
        LCDWriteString(LCD_Out_Buffer, 2, 1); // write to the second row
                                            // start at the first position
        k = k + 0.001;

        // delay a little
        for (j=0;j<1000000;j++){
            Nop();
        }
    }
    return 0;
}

//////FUNCTIONS

//////ISRs
// interrupt when the NU32 gets a character from the computer
void __ISR(_UART_1_VECTOR, ipl2) IntUart1Handler(void)
{
    // Is this an RX interrupt?
    if(INTGetFlag(INT_SOURCE_UART_RX(UART1)))
    {

        char data = UARTGetDataByte(UART1);
        PutCharacter(UART1,data);
        L1 = !L1;
        L2 = !L2;

        // Clear the RX interrupt Flag
        INTClearFlag(INT_SOURCE_UART_RX(UART1));
    }

    // We don't care about TX interrupt
    if(INTGetFlag(INT_SOURCE_UART_TX(UART1)))
    {
        INTClearFlag(INT_SOURCE_UART_TX(UART1));
    }
}

